pub struct ScheduledFunctionDeclaration {
pub name: String,
pub function_name: String,
pub cron: String,
pub input: Value,
}Fields
name: StringStable schedule name scoped to the owning module.
function_name: StringRuntime function enqueued when this schedule is due.
cron: StringStandard 5-field cron expression in UTC.
input: ValueTrait Implementations
Sourceimpl Clone for ScheduledFunctionDeclaration
impl Clone for ScheduledFunctionDeclaration
Sourcefn clone(&self) -> ScheduledFunctionDeclaration
fn clone(&self) -> ScheduledFunctionDeclaration
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScheduledFunctionDeclaration
impl Debug for ScheduledFunctionDeclaration
Sourceimpl<'de> Deserialize<'de> for ScheduledFunctionDeclaration
impl<'de> Deserialize<'de> for ScheduledFunctionDeclaration
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ScheduledFunctionDeclaration, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ScheduledFunctionDeclaration, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ScheduledFunctionDeclaration
Sourceimpl JsonSchema for ScheduledFunctionDeclaration
impl JsonSchema for ScheduledFunctionDeclaration
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for ScheduledFunctionDeclaration
impl Serialize for ScheduledFunctionDeclaration
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for ScheduledFunctionDeclaration